@@ -11,11 +11,11 @@ def create_file(filepath, content, **kwargs):
     Create a backup if required, then create new file using writelines
     Returns "file exists" if filepath already exists and overwrite = False
     """
-    if type(content) == str:
+    if isinstance(content, str):
         content = content.splitlines(True)  # keep line breaks
     if filepath.is_file():
         if kwargs.get("overwrite"):
-            backup = filepath.with_name(filepath.stem + " - old.py")
+            backup = filepath.with_name(f"{filepath.stem} - old.py")
             if backup.is_file():
                 os.remove(backup)
             filepath.rename(backup)
@@ -24,7 +24,7 @@ def create_file(filepath, content, **kwargs):
         else:
             print(f"\nⓘ Existing file preserved:\n  {filepath}")
             return "file exists"
-    with open(filepath, "a") as file:
+    with filepath.open("a") as file:
         file.writelines(content)
         print(f"\n✓ Created new file:\n  {filepath}")
 
@@ -34,13 +34,16 @@ def update_line(script_lines, old_line_starts, new_value):
     for index, line in enumerate(script_lines.copy()):
         if line.lstrip().startswith(old_line_starts):
             try:
-                if not new_value.startswith("["):
-                    new_value = f'"{new_value}"'  # Add quotation marks unless list
+                if isinstance(new_value, list):
+                    # Add quotation marks unless list
+                    new_value = ", ".join(new_value)
+                else:
+                    new_value = f'"{new_value}"'
                 script_lines[index] = old_line_starts + new_value.rstrip() + "\n"
                 print(
-                    f"\n✓ Updated script line {index+1}:\n{script_lines[index].rstrip()[:400]}"
+                    f"\n✓ Updated script line {index + 1}:\n{script_lines[index].rstrip()[:400]}"
                 )
                 break  # only update first occurrence
-            except:
+            except (IndexError, TypeError):
                 print(new_value, type(new_value))
     return script_lines
